@@ -70,14 +70,15 @@ def deaths_to_file():
         if i == 0: chunk.to_csv(filename, mode='w', header=True, index=False)
         else: chunk.to_csv(filename, mode='a', header=False, index=False)
 
-def deaths(regions = None, sex = None, age = None, start = None):
+def deaths(regions = None, start = None, sex = None, age = None, output = None, chunksize = 1):
     """Reads data from Eurostat, filters and saves to CSV.
     
     Args:
         regions (list, optional): Filter of countries.
-        
         start (datetime, optional): Start time. Will be rounded to week. Endtime is always end of data.
                                     Default is all the data (no filtering).
+        sex (str, optional): Sex to consider.
+        age (str, optional): Age to consider
     """
     chunksize = 1
     data = None
@@ -117,6 +118,8 @@ def deaths(regions = None, sex = None, age = None, start = None):
         else: data = data.append(chunk)
         logging.info(f"parsed {chunksize * (i + 1) * 10**3} lines")
     
+    if output is not None:
+        data.to_csv(output)
     return data
 
 __all__ = ["deaths"]
